<?php
/****************
Trovate questo e altri script su http://www.manuelmarangoni.it , descritti e commentati nei dettagli.

Autore: Manuel Marangoni
Data messa online dello script: 24 agosto 2012

Esempio complesso: unisce lo script per trasformare un indirizzo in coordinate e per calcolare la distanza tra due punti geografici.
In breve:
- con una funzione, passando l'indirizzo come parametro, estrae latitudine e longitudine e le inserisce in un unico array di due elementi
- con una seconda funzione, prende due indirizzi come parametri, li trasforma in coordinate geografiche (richiamando la prima funzione) e ritorna la loro distanza in chilometri.
- attraverso un ciclo for estrae la distanza tra un punto di origine e, ricorsivamente, tutti i cap di Verona; poi li stampa a video
****************/

define("MAPS_HOST", "maps.google.com");
define("KEY", "abcdefg");


//Trasforma l'indirizzo passato in coordinate latitudine-longitudine e lo ritorna in un array
//Recupera l'indirizzo passato in $address e, tramite le api geocode di Google Maps, lo trasforma in latitudine e longitudine.
function address_in_coord($address){

	$geocode_pending=true;
	
	//Initialize delay in geocode speed
	$delay=0;
	$base_url="http://".MAPS_HOST."/maps/geo?output=xml&key=".KEY;
	
	while($geocode_pending){
		
		$request_url = $base_url . "&q=" . urlencode($address);
		$xml=simplexml_load_file($request_url) or die("url not loading");
	
		$status = $xml->Response->Status->code;
		if (strcmp($status, "200") == 0){
			// Successful geocode
			$geocode_pending = false;
			$coordinates = $xml->Response->Placemark->Point->coordinates;
			$coordinatesSplit = explode(",", $coordinates);
			// Format: Longitude, Latitude, Altitude
			$lat = $coordinatesSplit[1];
			$lng = $coordinatesSplit[0];
			
			//echo $lat." --- ".$lng;
		  
			//punto di origine
			$array=array();
			$array[]=$lat;
			$array[]=$lng;
			
			return $array;
		  
		
		  
		}elseif(strcmp($status, "620")==0) {
		  // sent geocodes too fast
		  $delay += 100000;
		}else{
		  // failure to geocode
		  $geocode_pending=false;
		  return "Address ".$address." failed to geocoded. Received status ".$status."\n";
		}
		usleep($delay);
		
	}//while

}


//Ritorna la distanza tra due punti (ognuno con proprie latitudine e longitudine)
//$origine = stringa contenente l'indirizzo del punto di origine
//$destinazione = stringa contenente l'indirizzo del punto di destinazione
function distanza($origine, $destinazione){
	
	$origine_arr=address_in_coord($origine);
	$destinazione_arr=address_in_coord($destinazione);
	
	$lat1=$origine_arr[0];
	$lon1=$origine_arr[1];
	
	$lat2=$destinazione_arr[0];
	$lon2=$destinazione_arr[1];
	
	$distance = (3958*3.1415926*sqrt(($lat2-$lat1)*($lat2-$lat1) + cos($lat2/57.29578)*cos($lat1/57.29578)*($lon2-$lon1)*($lon2-$lon1))/180); 
	
	return $distance;
	
}


//stampo la distanza tra tutti i cap di Verona (da 37121 a 37142) e il punto di origine
$origine="Via Vittorio Veneto Cerea Vr";
for($i=37121; $i<37143; $i++){
	if($i!=37130 and $i!=37140){ //escludo i cap nel range non di Verona
		echo distanza($i.' Verona', $origine)." Cap: ".$i."<br />";
	}
}
?>

